import pkg_resources

__title__ = 'marquee'
try:
    __version__ = pkg_resources.require('marquee')[0].version
except (AttributeError, pkg_resources.DistributionNotFound, IndexError):
    __version__ = 'unknown'



"""marquee logging handler."""
from logging import Handler

import boto3

from marquee.formatter import MarqueeFormatter


class CloudWatchEventsHandler(Handler):

    def __init__(self, detail_type=None, *args, **kwargs):
        """Overridden __init__ method.

        Will set detail_type on handler object then invoke Handler __init__
        with any passed in arguments
        """
        self.detail_type = detail_type
        super(CloudWatchEventsHandler, self).__init__(*args, **kwargs)

    def emit(self, record):
        """Overridden emit method.

        This will emit the log message to CloudWatch Events. Permissions
        and target account all set according to normal boto resolution.
        """
        client = boto3.client('events')
        source = self.formatter.source if isinstance(self.formatter, MarqueeFormatter) else __name__
        detail_type = self.detail_type if self.detail_type is not None else 'marquee'
        return client.put_events(
            Entries=[
                {
                    'Time': self.formatter.formatTime(record),
                    'Source': source,
                    'DetailType': detail_type,
                    'Detail': self.format(record)
                }
            ]
        )



"""marquee logging formatter."""
import json
from logging import Formatter


class MarqueeFormatter(Formatter):
    def __init__(self, source=None, *args, **kwargs):
        """marquee logging formatter.

        Args:
            source (str): application from which your are logging
        """
        self.source = source if source is not None else __name__
        super(MarqueeFormatter, self).__init__(*args, **kwargs)

    def format(self, record):
        """Overridden format method.

        This will create a json object containing data for the CloudWatch Event.
        """
        return json.dumps({
            'source': self.source,
            'created': self.formatTime(record),
            'level': record.levelname,
            'level_number': record.levelno,
            'message': record.msg
        })


class MarqueeEventFormatter(MarqueeFormatter):
    def __init__(self, event_type=None, source=None, *args, **kwargs):
        """marquee event formatter.
        """
        self.source = source if source is not None else __name__
        self.event_type = event_type if event_type else self.source
        super(MarqueeFormatter, self).__init__(*args, **kwargs)

    def format(self, record):
        """Overridden format method.
        This will create a json object containing data for the CloudWatch Event.
        """
        return json.dumps({
            'source': self.source,
            'created': self.formatTime(record),
            'event-type': self.event_type,
            'event': record.msg
        })




#!/usr/bin/env python
from setuptools import setup, find_packages

with open('VERSION') as version_file:
    version = version_file.read().strip()

with open('README.rst') as readme_file:
    readme = readme_file.read()

install_requires = [
    'boto3>=1.4.0',
]

setup(
    name='marquee',
    version=version,
    description='A simple Python logging formatter and handler for CloudWatch Events',
    long_description=readme,
    author='Herkermer Sherwood',
    author_email='theherk@gmail.com',
    packages=find_packages(),
    platforms=['all'],
    install_requires=install_requires,
    setup_requires=['pytest-runner'],
    tests_require=[
        'mock',
        'pytest'
    ]
)
